==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/logic/kotlin/outputs/ExpressionRootResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.logic.kotlin.outputs

import kotlin.Any
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List

/**
 * The expression root.
 * @property error The azure resource error info.
 * @property path The path.
 * @property subexpressions The sub expressions.
 * @property text The text.
 * @property value
 */
public data class ExpressionRootResponse(
    public val error: AzureResourceErrorInfoResponse? = null,
    public val path: String? = null,
    public val subexpressions: List<ExpressionResponse>? = null,
    public val text: String? = null,
    public val `value`: Any? = null,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.logic.outputs.ExpressionRootResponse):
            ExpressionRootResponse = ExpressionRootResponse(
            error = javaType.error().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.logic.kotlin.outputs.AzureResourceErrorInfoResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
            path = javaType.path().map({ args0 -> args0 }).orElse(null),
            subexpressions = javaType.subexpressions().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.logic.kotlin.outputs.ExpressionResponse.Companion.toKotlin(args0)
                })
            }),
            text = javaType.text().map({ args0 -> args0 }).orElse(null),
            `value` = javaType.`value`().map({ args0 -> args0 }).orElse(null),
        )
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/logic/kotlin/outputs/ExpressionRootResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.logic.kotlin.outputs

import kotlin.Any
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List

/**
 * The expression root.
 * @property error The azure resource error info.
 * @property path The path.
 * @property subexpressions The sub expressions.
 * @property text The text.
 * @property value
 */
public data class ExpressionRootResponse(
    public val error: AzureResourceErrorInfoResponse? = null,
    public val path: String? = null,
    public val subexpressions: List<ExpressionResponse>? = null,
    public val text: String? = null,
    public val `value`: Any? = null,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.logic.outputs.ExpressionRootResponse): ExpressionRootResponse = ExpressionRootResponse(
            error = javaType.error().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.logic.kotlin.outputs.AzureResourceErrorInfoResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
            path = javaType.path().map({ args0 -> args0 }).orElse(null),
            subexpressions = javaType.subexpressions().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.logic.kotlin.outputs.ExpressionResponse.Companion.toKotlin(args0)
                })
            }),
            text = javaType.text().map({ args0 -> args0 }).orElse(null),
            `value` = javaType.`value`().map({ args0 -> args0 }).orElse(null),
        )
    }
}
